@@ -40,14 +40,14 @@ static gchar *xfercmd = NULL;
 typedef struct
 {
 	 gboolean		 checkspace, color, disabledownloadtimeout, ilovecandy,
-				totaldl, usesyslog, verbosepkglists, is_check;
+				noprogressbar, totaldl, usesyslog, verbosepkglists, is_check;
 
 	 gchar			*arch, *cleanmethod, *dbpath, *gpgdir, *logfile,
 				*root, *xfercmd;
 
 	 alpm_list_t		*cachedirs, *holdpkgs, *ignoregroups,
 				*ignorepkgs, *localfilesiglevels, *noextracts,
-				*noupgrades, *remotefilesiglevels;
+				*noupgrades, *remotefilesiglevels, *hookdirs;
 
 	 alpm_list_t		*sections;
 	 GRegex			*xrepo, *xarch;
@@ -106,6 +106,7 @@ pk_alpm_config_free (PkAlpmConfig *config)
 	FREELIST (config->noextracts);
 	FREELIST (config->noupgrades);
 	FREELIST (config->remotefilesiglevels);
+	FREELIST (config->hookdirs);
 
 	alpm_list_free_inner (config->sections, pk_alpm_config_section_free);
 	alpm_list_free (config->sections);
@@ -146,6 +147,14 @@ pk_alpm_config_set_ilovecandy (PkAlpmConfig *config)
 	config->ilovecandy = TRUE;
 }
 
+static void
+pk_alpm_config_set_noprogressbar (PkAlpmConfig *config)
+{
+	g_return_if_fail (config != NULL);
+
+	config->noprogressbar = TRUE;
+}
+
 static void
 pk_alpm_config_set_totaldl (PkAlpmConfig *config)
 {
@@ -182,6 +191,7 @@ static const PkAlpmConfigBoolean pk_alpm_config_boolean_options[] = {
 	{ "Color", pk_alpm_config_set_color },
 	{ "DisableDownloadTimeout", pk_alpm_config_set_disabledownloadtimeout },
 	{ "ILoveCandy", pk_alpm_config_set_ilovecandy },
+	{ "NoProgressBar", pk_alpm_config_set_noprogressbar },
 	{ "TotalDownload", pk_alpm_config_set_totaldl },
 	{ "UseSyslog", pk_alpm_config_set_usesyslog },
 	{ "VerbosePkgLists", pk_alpm_config_set_verbosepkglists },
@@ -360,6 +370,7 @@ static const PkAlpmConfigList pk_alpm_config_list_options[] = {
 	{ "NoUpgrade", G_STRUCT_OFFSET (PkAlpmConfig, noupgrades) },
 	{ "RemoteFileSigLevel", G_STRUCT_OFFSET (PkAlpmConfig,
 						 remotefilesiglevels) },
+	{ "HookDir", G_STRUCT_OFFSET (PkAlpmConfig, hookdirs) },
 	{ NULL, 0 }
 };
 
@@ -599,6 +610,11 @@ pk_alpm_config_parse (PkAlpmConfig *config, const gchar *filename,
 			continue;
 		}
 
+		if (g_strcmp0 (key, "ParallelDownloads") == 0 && str != NULL) {
+			/* Ignore "ParallelDownloads" key instead of crashing */
+			continue;
+		}
+
 		/* report errors from above */
 		g_set_error (&e, PK_ALPM_ERROR, PK_ALPM_ERR_CONFIG_INVALID,
 			     "unrecognised directive '%s'", key);
@@ -616,7 +632,7 @@ static alpm_handle_t *
 pk_alpm_config_initialize_alpm (PkAlpmConfig *config, GError **error)
 {
 	alpm_handle_t *handle;
-	alpm_errno_t errno;
+	alpm_errno_t alpm_err;
 	gsize dir = 1;
 
 	g_return_val_if_fail (config != NULL, FALSE);
@@ -635,8 +651,10 @@ pk_alpm_config_initialize_alpm (PkAlpmConfig *config, GError **error)
 	}
 
 	if (config->is_check) {
+		gchar* path;
+
 		g_free(config->dbpath);
-		gchar* path = g_strconcat (config->root,
+		path = g_strconcat (config->root,
 						 "/var/lib/PackageKit/alpm" + dir,
 						 NULL);
 		g_mkdir_with_parents(path, 0755);
@@ -644,10 +662,10 @@ pk_alpm_config_initialize_alpm (PkAlpmConfig *config, GError **error)
 	}
 
 
-	handle = alpm_initialize (config->root, config->dbpath, &errno);
+	handle = alpm_initialize (config->root, config->dbpath, &alpm_err);
 	if (handle == NULL) {
-		g_set_error_literal (error, PK_ALPM_ERROR, errno,
-				     alpm_strerror (errno));
+		g_set_error_literal (error, PK_ALPM_ERROR, alpm_err,
+				     alpm_strerror (alpm_err));
 		return handle;
 	}
 
@@ -658,9 +676,9 @@ pk_alpm_config_initialize_alpm (PkAlpmConfig *config, GError **error)
 	}
 
 	if (alpm_option_set_gpgdir (handle, config->gpgdir) < 0) {
-		errno = alpm_errno (handle);
-		g_set_error (error, PK_ALPM_ERROR, errno, "GPGDir: %s",
-			     alpm_strerror (errno));
+		alpm_err = alpm_errno (handle);
+		g_set_error (error, PK_ALPM_ERROR, alpm_err, "GPGDir: %s",
+			     alpm_strerror (alpm_err));
 		return handle;
 	}
 
@@ -678,9 +696,9 @@ pk_alpm_config_initialize_alpm (PkAlpmConfig *config, GError **error)
 	}
 
 	if (alpm_option_set_logfile (handle, config->logfile) < 0) {
-		errno = alpm_errno (handle);
-		g_set_error (error, PK_ALPM_ERROR, errno, "LogFile: %s",
-			     alpm_strerror (errno));
+		alpm_err = alpm_errno (handle);
+		g_set_error (error, PK_ALPM_ERROR, alpm_err, "LogFile: %s",
+			     alpm_strerror (alpm_err));
 		return handle;
 	}
 
@@ -693,9 +711,9 @@ pk_alpm_config_initialize_alpm (PkAlpmConfig *config, GError **error)
 
 	/* alpm takes ownership */
 	if (alpm_option_set_cachedirs (handle, config->cachedirs) < 0) {
-		errno = alpm_errno (handle);
-		g_set_error (error, PK_ALPM_ERROR, errno, "CacheDir: %s",
-			     alpm_strerror (errno));
+		alpm_err = alpm_errno (handle);
+		g_set_error (error, PK_ALPM_ERROR, alpm_err, "CacheDir: %s",
+			     alpm_strerror (alpm_err));
 		return handle;
 	}
 	config->cachedirs = NULL;
@@ -791,7 +809,7 @@ static gboolean
 pk_alpm_config_configure_repos (PkBackend *backend, PkAlpmConfig *config,
 				   alpm_handle_t *handle, GError **error)
 {
-	alpm_siglevel_t base, level, mask, local, remote;
+	alpm_siglevel_t base, level = 0, mask = 0, local, remote;
 	const alpm_list_t *i;
 	PkAlpmConfigSection *options;
 
@@ -870,7 +888,7 @@ pk_alpm_spawn (const gchar *command)
 }
 
 static gint
-pk_alpm_fetchcb (const gchar *url, const gchar *path, gint force)
+pk_alpm_fetchcb (void *ctx, const gchar *url, const gchar *path, gint force)
 {
 	GRegex *xo, *xi;
 	gint result = 0;
@@ -942,6 +960,9 @@ pk_alpm_config_configure_alpm (PkBackend *backend, PkAlpmConfig *config, GError
 {
 	PkBackendAlpmPrivate *priv = pk_backend_get_user_data (config->backend);
 	alpm_handle_t *handle;
+	gchar **arches;
+	gint i;
+	alpm_list_t *arches_list = NULL;
 
 	g_return_val_if_fail (config != NULL, FALSE);
 
@@ -951,7 +972,14 @@ pk_alpm_config_configure_alpm (PkBackend *backend, PkAlpmConfig *config, GError
 
 	alpm_option_set_checkspace (handle, config->checkspace);
 	alpm_option_set_usesyslog (handle, config->usesyslog);
-	alpm_option_set_arch (handle, config->arch);
+
+	arches = g_strsplit (config->arch, ",", -1);
+	for (i = 0; arches[i]; i++) {
+		arches_list = alpm_list_add (arches_list, arches[i]);
+	}
+	alpm_option_set_architectures (handle, arches_list);
+	g_strfreev (arches);
+	alpm_list_free (arches_list);
 
 	/* backend takes ownership */
 	g_free (xfercmd);
@@ -959,9 +987,9 @@ pk_alpm_config_configure_alpm (PkBackend *backend, PkAlpmConfig *config, GError
 	config->xfercmd = NULL;
 
 	if (xfercmd != NULL) {
-		alpm_option_set_fetchcb (handle, pk_alpm_fetchcb);
+		alpm_option_set_fetchcb (handle, pk_alpm_fetchcb, NULL);
 	} else {
-		alpm_option_set_fetchcb (handle, NULL);
+		alpm_option_set_fetchcb (handle, NULL, NULL);
 	}
 
 	/* backend takes ownership */
@@ -985,6 +1013,10 @@ pk_alpm_config_configure_alpm (PkBackend *backend, PkAlpmConfig *config, GError
 	alpm_option_set_noupgrades (handle, config->noupgrades);
 	config->noupgrades = NULL;
 
+	/* alpm takes ownership */
+	alpm_option_set_noupgrades (handle, config->hookdirs);
+	config->hookdirs = NULL;
+
 	pk_alpm_config_configure_repos (backend, config, handle, error);
 
 	return handle;
