@@ -30,6 +30,7 @@
 #include "pk-alpm-error.h"
 #include "pk-alpm-transaction.h"
 #include "pk-alpm-update.h"
+#include "pk-alpm-packages.h"
 
 static gboolean
 pk_alpm_transaction_sync_targets (PkBackendJob *job, const gchar **packages, gboolean update, GError **error)
@@ -53,32 +54,41 @@ pk_alpm_transaction_sync_targets (PkBackendJob *job, const gchar **packages, gbo
 		}
 
 		if (i == NULL) {
-			alpm_errno_t errno = ALPM_ERR_DB_NOT_FOUND;
-			g_set_error (error, PK_ALPM_ERROR, errno, "%s/%s: %s",
-				     repo, name, alpm_strerror (errno));
+			alpm_errno_t alpm_err = ALPM_ERR_DB_NOT_FOUND;
+			g_set_error (error, PK_ALPM_ERROR, alpm_err, "%s/%s: %s",
+				     repo, name, alpm_strerror (alpm_err));
 			return FALSE;
 		}
 
 		pkg = alpm_db_get_pkg (i->data, name);
+		alpm_pkg_t *dep_to_remove = pk_alpm_pkg_replaces(priv->localdb, pkg);
+		if (dep_to_remove) {
+			g_debug("scheduling to remove %s for %s", alpm_pkg_get_name(dep_to_remove), name);
+			alpm_remove_pkg(priv->alpm, dep_to_remove);
+		}
 
 		if (update) { // libalpm only checks for ignorepkgs on an update
 			const alpm_list_t *ignorepkgs, *ignoregroups, *group_iter;
 
 			ignorepkgs = alpm_option_get_ignorepkgs (priv->alpm);
-			if (alpm_list_find_str (ignorepkgs, alpm_pkg_get_name (pkg)) != NULL)
+			if (alpm_list_find_str (ignorepkgs, alpm_pkg_get_name (pkg)) != NULL) {
+				pk_alpm_pkg_emit(job, pkg, PK_INFO_ENUM_BLOCKED);
 				goto cont;
+			}
 
 			ignoregroups = alpm_option_get_ignoregroups (priv->alpm);
 			for (group_iter = alpm_pkg_get_groups (pkg); group_iter != NULL; group_iter = group_iter->next) {
-				if (alpm_list_find_str (ignoregroups, i->data) != NULL)
-					pk_alpm_pkg_emit (job, pkg, PK_INFO_ENUM_BLOCKED); goto cont;
+				if (alpm_list_find_str (ignoregroups, i->data) != NULL) {
+					pk_alpm_pkg_emit (job, pkg, PK_INFO_ENUM_BLOCKED);
+					goto cont;
+				}
 			}
 		}
 
 		if (pkg == NULL || alpm_add_pkg (priv->alpm, pkg) < 0) {
-			alpm_errno_t errno = alpm_errno (priv->alpm);
-			g_set_error (error, PK_ALPM_ERROR, errno, "%s/%s: %s",
-				     repo, name, alpm_strerror (errno));
+			alpm_errno_t alpm_err = alpm_errno (priv->alpm);
+			g_set_error (error, PK_ALPM_ERROR, alpm_err, "%s/%s: %s",
+				     repo, name, alpm_strerror (alpm_err));
 			return FALSE;
 		}
 
@@ -176,7 +186,7 @@ pk_backend_sync_thread (PkBackendJob* job, GVariant* params, gpointer p)
 	PkBackendAlpmPrivate *priv = pk_backend_get_user_data (backend);
 	PkBitfield flags;
 	gboolean only_trusted;
-	const alpm_list_t *i;
+	alpm_list_t *i;
 	alpm_list_t *asdeps = NULL, *asexplicit = NULL;
 	alpm_transflag_t alpm_flags = 0;
 	const gchar** package_ids;
@@ -188,11 +198,10 @@ pk_backend_sync_thread (PkBackendJob* job, GVariant* params, gpointer p)
 	if (!only_trusted && !pk_alpm_disable_signatures (backend, &error))
 		goto out;
 
-	if ((gboolean)p) {
+	if (p) {
 		i = alpm_get_syncdbs(priv->alpm);
-		for (; i != NULL; i = i->next) {
-			pk_alpm_update_database(job, TRUE, i->data, &error);
-		}
+		pk_alpm_refresh_databases (job, TRUE, i, &error);
+		pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
 	}
 
 	/* download only */
@@ -200,7 +209,7 @@ pk_backend_sync_thread (PkBackendJob* job, GVariant* params, gpointer p)
 		alpm_flags |= ALPM_TRANS_FLAG_DOWNLOADONLY;
 
 	if (pk_alpm_transaction_initialize (job, alpm_flags, NULL, &error) &&
-	    pk_alpm_transaction_sync_targets (job, package_ids, (gboolean)p, &error) &&
+	    pk_alpm_transaction_sync_targets (job, package_ids, p ? TRUE : FALSE, &error) &&
 	    pk_alpm_transaction_simulate (job, &error)) {
 
 		if (pk_bitfield_contain (flags, PK_TRANSACTION_FLAG_ENUM_SIMULATE)) { /* simulation */
@@ -263,7 +272,7 @@ pk_backend_update_packages (PkBackend *self,
 			    PkBitfield transaction_flags,
 			    gchar **package_ids)
 {
-	pk_alpm_run (job, PK_STATUS_ENUM_SETUP, pk_backend_sync_thread, TRUE);
+	pk_alpm_run (job, PK_STATUS_ENUM_SETUP, pk_backend_sync_thread, (void *)TRUE);
 }
 
 void
