@@ -214,8 +214,8 @@ static void backend_depends_on_or_requires_thread(PkBackendJob *job, GVariant *p
             return;
         }
 
-        const pkgCache::VerIterator &ver = apt->aptCacheFile()->resolvePkgID(pi);
-        if (ver.end()) {
+        const PkgInfo &pkInfo = apt->aptCacheFile()->resolvePkgID(pi);
+        if (pkInfo.ver.end()) {
             pk_backend_job_error_code(job,
                                       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
                                       "Couldn't find package %s",
@@ -224,9 +224,9 @@ static void backend_depends_on_or_requires_thread(PkBackendJob *job, GVariant *p
         }
 
         if (role == PK_ROLE_ENUM_DEPENDS_ON) {
-            apt->getDepends(output, ver, recursive);
+            apt->getDepends(output, pkInfo.ver, recursive);
         } else {
-            apt->getRequires(output, ver, recursive);
+            apt->getRequires(output, pkInfo.ver, recursive);
         }
     }
 
@@ -281,8 +281,8 @@ static void backend_get_files_thread(PkBackendJob *job, GVariant *params, gpoint
             return;
         }
 
-        const pkgCache::VerIterator &ver = apt->aptCacheFile()->resolvePkgID(pi);
-        if (ver.end()) {
+        const PkgInfo &pkInfo = apt->aptCacheFile()->resolvePkgID(pi);
+        if (pkInfo.ver.end()) {
             pk_backend_job_error_code(job,
                                       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
                                       "Couldn't find package %s",
@@ -352,15 +352,13 @@ void pk_backend_get_details_local(PkBackend *backend, PkBackendJob *job, gchar *
 
 static void backend_get_files_local_thread(PkBackendJob *job, GVariant *params, gpointer user_data)
 {
-    gchar **files = nullptr;
+    g_autofree gchar **files = nullptr;
     g_variant_get(params, "(^a&s)",
                   &files);
-
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
 
-    for (int i = 0; i < g_strv_length(files); ++i) {
+    for (guint i = 0; files[i] != nullptr; ++i)
         apt->emitPackageFilesLocal(files[i]);
-    }
 }
 
 void pk_backend_get_files_local(PkBackend *backend, PkBackendJob *job, gchar **files)
@@ -407,9 +405,7 @@ void pk_backend_get_updates(PkBackend *backend, PkBackendJob *job, PkBitfield fi
 static void backend_what_provides_thread(PkBackendJob *job, GVariant *params, gpointer user_data)
 {
     PkBitfield filters;
-    const gchar *provides_text;
     gchar **values;
-    bool error = false;
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
 
     g_variant_get(params, "(t^a&s)",
@@ -512,13 +508,13 @@ static void pk_backend_download_packages_thread(PkBackendJob *job, GVariant *par
                 break;
             }
 
-            const pkgCache::VerIterator &ver = apt->aptCacheFile()->resolvePkgID(pi);
+            const PkgInfo &pkInfo = apt->aptCacheFile()->resolvePkgID(pi);
             // Ignore packages that could not be found or that exist only due to dependencies.
-            if (ver.end()) {
+            if (pkInfo.ver.end()) {
                 _error->Error("Can't find this package id \"%s\".", pi);
                 continue;
             } else {
-                if(!ver.Downloadable()) {
+                if(!pkInfo.ver.Downloadable()) {
                     _error->Error("No downloadable files for %s,"
                                   "perhaps it is a local or obsolete" "package?",
                                   pi);
@@ -527,7 +523,7 @@ static void pk_backend_download_packages_thread(PkBackendJob *job, GVariant *par
 
                 string storeFileName;
                 if (!apt->getArchive(&fetcher,
-                                     ver,
+                                     pkInfo.ver,
                                      directory,
                                      storeFileName)) {
                     return;
@@ -572,11 +568,11 @@ static void pk_backend_refresh_cache_thread(PkBackendJob *job, GVariant *params,
         g_debug("Failed to create apt cache");
         return;
     }
-    
+
     PkBackend *backend = PK_BACKEND(pk_backend_job_get_backend(job));
     if (pk_backend_is_online(backend)) {
         apt->refreshCache();
-        
+
         if (_error->PendingError() == true) {
             show_errors(job, PK_ERROR_ENUM_CANNOT_FETCH_SOURCES, true);
         }
@@ -611,7 +607,7 @@ static void pk_backend_resolve_thread(PkBackendJob *job, GVariant *params, gpoin
     PkgList pkgs = apt->resolvePackageIds(search);
 
     // It's faster to emit the packages here rather than in the matching part
-    apt->emitPackages(pkgs, filters);
+    apt->emitPackages(pkgs, filters, PK_INFO_ENUM_UNKNOWN, true);
 }
 
 void pk_backend_resolve(PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **packages)
@@ -720,7 +716,7 @@ static void backend_search_package_thread(PkBackendJob *job, GVariant *params, g
     }
 
     // It's faster to emit the packages here than in the matching part
-    apt->emitPackages(output, filters);
+    apt->emitPackages(output, filters, PK_INFO_ENUM_UNKNOWN, true);
 
     pk_backend_job_set_percentage(job, 100);
 }
@@ -741,7 +737,6 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
     PkBitfield transaction_flags = 0;
     gboolean allow_deps = false;
     gboolean autoremove = false;
-    bool fileInstall = false;
     gchar **full_paths = NULL;
     gchar **package_ids = NULL;
 
@@ -751,7 +746,6 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
         g_variant_get(params, "(t^a&s)",
                       &transaction_flags,
                       &full_paths);
-        fileInstall = true;
     } else if (role == PK_ROLE_ENUM_REMOVE_PACKAGES) {
         g_variant_get(params, "(t^a&sbb)",
                       &transaction_flags,
@@ -768,14 +762,6 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
                       &package_ids);
     }
 
-    // Check if we should only simulate the install (calculate dependencies)
-    bool simulate;
-    simulate = pk_bitfield_contain(transaction_flags, PK_TRANSACTION_FLAG_ENUM_SIMULATE);
-
-    // Check if we should only download all the required packages for this transaction
-    bool downloadOnly;
-    downloadOnly = pk_bitfield_contain(transaction_flags, PK_TRANSACTION_FLAG_ENUM_ONLY_DOWNLOAD);
-
     // Check if we should fix broken packages
     bool fixBroken = false;
     if (role == PK_ROLE_ENUM_REPAIR_SYSTEM) {
@@ -884,7 +870,6 @@ static void backend_repo_manager_thread(PkBackendJob *job, GVariant *params, gpo
     bool found = false;
     // generic
     PkRoleEnum role;
-    AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
 
     role = pk_backend_job_get_role(job);
     if (role == PK_ROLE_ENUM_GET_REPO_LIST) {
@@ -923,7 +908,7 @@ static void backend_repo_manager_thread(PkBackendJob *job, GVariant *params, gpo
         }
 
         string sections = souceRecord->joinedSections();
-        
+
         string repoId = souceRecord->repoId();
 
         if (role == PK_ROLE_ENUM_GET_REPO_LIST) {
